ad_page_contract {
    Record user response for one acknowledgement.
    
    @author Peter Alberer(peter@alberer.com)
    @creation-date 2003-10-06
} {
    id:notnull
    {mode "show"}
    {user_id ""}
    {return_url "/acknowledgements/"}
    {response ""}
}

if { $user_id == "" } {
	set user_id [ad_get_user_id]
	set override_mode 0
} else {
	#if we get a user_id via url vars it means that the login-page redirected the
	#user to us because the user has not yet confirmed a term of use.
	#we do not login the user before she has confirmed the term of use because
	#otherwise she could go wherever she wanted on the site.
	#in order to be able to authenticate the user despite that, we force the
	#confirm mode "password".
	set override_mode 1
	set return_url "/register/"
}

set page_title [_ acknowledgement.sign_ack]
set context [list $page_title]

db_1row get_data {
	select title, description, due_date, ack_mode, ack_phrase, resp.ack_date
	from acknowledgments a left join
	(select ack_id, ack_date from acknowledgment_responses where user_id = :user_id) resp
	on a.ack_id = resp.ack_id
	where a.ack_id = :id
}

if { $ack_date != "" } { 
	ad_return_error [_ acknowledgement.ack_signed_1] [_ acknowledgement.ack_signed_2]
	ad_script_abort
}

if { $override_mode == 1 } { set ack_mode "password" }

if { $mode == "show" } {
	switch $ack_mode {
		"checkbox" {
			set confirm_html "<p>[_ acknowledgement.sign_checkbox] <input type='checkbox' name='response'>"
		}
		"phrase" {
			set confirm_html "<p>[_ acknowledgement.sign_phrase [list word \"$ack_phrase\"]] <br><input type='text' name='response'>"
		}
		"password" {
			set confirm_html "<p>[_ acknowledgement.sign_password] <br><input type='password' name='response'>"
		}
	}
} else {
	set success 0
	switch $ack_mode {
		"checkbox" {
			if { $response == "on" } {
				acknowledgement::record_response $id $user_id
				set success 1
			}
		}
		"phrase" {
			if { $response == $ack_phrase } {
				acknowledgement::record_response $id $user_id
				set success 1
			}
		}
		"password" {
			if { [ad_check_password $user_id $response] } {
				acknowledgement::record_response $id $user_id
				set success 1
			}
		}
	}
	if { $success == 1 } {
		set html "[_ acknowledgement.thanks_for_signing]<br>"
		append html "<a href='$return_url'>[_ acknowledgement.back]</a>"
	} else {
		set html "[_ acknowledgement.thanks_for_not_signing]<br>"
	}
}
